kinnow_mqtt library

Classes

ConnAckEvent
The event when the broker acknowledges the connection and sends a connAck packet
ConnAckPacket
A packet sent by the broker to thr client in response to a connection request
ConnackTimedOut
The event when the broker does not respond to a connect packet withing three seconds
ConnectPacket
The connect packet sent to initiate connection
ConnectPacketWillProperties
The Last Will Properties
DisconnectPacket
A packet sent by the server or client to close the connection
FileMqttMessageStorage
implements persistent storage pf Mqtt Messages in files
KinnowMqttClient
The main Mqtt Client class
MalformedPacket
The event when the broker sends a packet that cannot be understood by the library
MqttEvent
A base class for all Mqtt Events.
MqttMessageStorage
MqttMessageStorageRow
MqttNetworkConnection
The base class for network connections that can be used for mqtt
NetworkConnectionFailure
The event when a socket/SSL-socket/websocket connection attempt failed
NetworkEnded
The event when an established network connection becomes disconnected after successful connecting
PingReqSent
The event when a ping request packet is sent
PingRespNotReceived
The event when a ping request was sent but a ping response was not received within the keep alive duration
PingRespReceived
The event when a ping response packet is received
PubackPacket
Packet sent in response to a QoS1 message
PubcompPacket
Sent in response to a PubrelPacket for Qos2 messages
PubrecPacket
Packet sent in response to a QoS2 Publish message
PubrelPacket
Sent in response to a PubrecPacket for Qos2 messages
RxPublishPacket
A publish packet sent by the sever to the client
ShutDown
The event when the client has reached an unrecoverable state.
SslTcpMqttNetworkConnection
Mqtt Connection that uses TCP sockets with encryption using TLS/SSL
StoredMessageSentQos0
StoredMessageSentQos1
StoredMessageSentQos2
StringOrBytes
A class for when data can be provided as either bytes or strings
SubackPacket
Packet sent by server in response to a SubscribePacket
SubscribePacket
Packet sent by client to subscribe to one or more topics
TcpMqttNetworkConnection
Mqtt Connection that uses simple TCP sockets without encryption
TopicSubscription
The subscription properties for a single topic
TxPublishPacket
A Publish packet sent from client to server
UnsubackPacket
Packet sent by server in reply to a UnsubscribePacket
UnsubscribePacket
Packet sent by client to unsubscribe from one or more topics
WebSocketMqttNetworkConnection
Mqtt Connection that uses WebSockets

Enums

ConnectReasonCode
The Reason codes that can be sent in the ConnAck packet according to the specification
DisconnectReasonCode
The Disconnection Reason provided by the server or the client in the disconnect packet
MqttFormatIndicator
MqttQos
RetainHandlingOption
How to handle retained messages
ShutdownType
The cause of the client shutting down
SubackReasonCode
success or failure reason for a topic subscription
UnsubackReasonCode