ConnectReasonCode enum

The Reason codes that can be sent in the ConnAck packet according to the specification

Inheritance
Available extensions

Values

success → const ConnectReasonCode
unspecifiedError → const ConnectReasonCode
malformedPacket → const ConnectReasonCode
protocolError → const ConnectReasonCode
implementationSpecificError → const ConnectReasonCode
unsupportedProtocolVersion → const ConnectReasonCode
clientIdentifierNotValid → const ConnectReasonCode
badUserNameOrPassword → const ConnectReasonCode
notAuthorized → const ConnectReasonCode
serverUnavailable → const ConnectReasonCode
serverBusy → const ConnectReasonCode
banned → const ConnectReasonCode
badAuthenticationMethod → const ConnectReasonCode
topicNameInvalid → const ConnectReasonCode
packetTooLarge → const ConnectReasonCode
quotaExceeded → const ConnectReasonCode
payloadFormatInvalid → const ConnectReasonCode
retainNotSupported → const ConnectReasonCode
qosNotSupported → const ConnectReasonCode
useAnotherServer → const ConnectReasonCode
serverMoved → const ConnectReasonCode
connectionRateExceeded → const ConnectReasonCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConnectReasonCode>
A constant List of the values in this enum, in order of their declaration.