SubackReasonCode enum

success or failure reason for a topic subscription

Inheritance
Available extensions

Values

grantedQoS0 → const SubackReasonCode
grantedQoS1 → const SubackReasonCode
grantedQoS2 → const SubackReasonCode
unspecifiedError → const SubackReasonCode
implementationSpecificError → const SubackReasonCode
notAuthorized → const SubackReasonCode
topicFilterInvalid → const SubackReasonCode
packetIdentifierInUse → const SubackReasonCode
quotaExceeded → const SubackReasonCode
sharedSubscriptionsNotSupported → const SubackReasonCode
subscriptionIdentifiersNotSupported → const SubackReasonCode
wildcardSubscriptionsNotSupported → const SubackReasonCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubackReasonCode>
A constant List of the values in this enum, in order of their declaration.